@@ -134,6 +134,9 @@ def format_doc_diffs(left: Dict, right: Dict) -> Iterable[str]:
         for offset in doc_diffs.tree["dictionary_item_removed"].items:
             offset: DiffLevel
             out.append(f"    {clean_offset(offset.path())} = {repr(offset.t1)}")
+
+    # If pytest verbose:
+    out.extend(("Full output document: ", repr(left)))
     return out
 
 
