@@ -48,6 +48,33 @@ def test_prepare_l8_l1_usgs_tarball(l1_ls8_folder, l1_ls8_folder_md_expected):
     )
 
 
+def test_prepare_l8_l1_c2(
+    tmp_path: Path, l1_c2_ls8_folder: Path, l1_c2_ls8_usgs_expected: Dict
+):
+    """Run prepare script with a source telemetry data and unique producer."""
+    assert l1_c2_ls8_folder.exists(), "Test data missing(?)"
+
+    output_path = tmp_path
+    expected_metadata_path = (
+        output_path
+        / "090"
+        / "084"
+        / "LC08_L1TP_090084_20160121_20200907_02_T1.odc-metadata.yaml"
+    )
+    check_prepare_outputs(
+        invoke_script=landsat_l1_prepare.main,
+        run_args=[
+            "--output-base",
+            output_path,
+            "--producer",
+            "usgs.gov",
+            l1_c2_ls8_folder,
+        ],
+        expected_doc=l1_c2_ls8_usgs_expected,
+        expected_metadata_path=expected_metadata_path,
+    )
+
+
 def test_prepare_l8_l1_tarball_with_source(
     tmp_path: Path, l1_ls8_folder: Path, ls8_telemetry_path, l1_ls8_ga_expected: Dict
 ):
@@ -61,7 +88,6 @@ def test_prepare_l8_l1_tarball_with_source(
         / "084"
         / "LC08_L1TP_090084_20160121_20170405_01_T1.odc-metadata.yaml"
     )
-
     check_prepare_outputs(
         invoke_script=landsat_l1_prepare.main,
         run_args=[
